# rrts
## What is it
A repository of Python2 implemented RRT*[1]-based algorithms for Path Planning of Autonomous Driving. Currently, including variants of RRT* and bi-RRT* for rather static environments (Parking lots, narrow space).
## How to use
TBD
## Reference
[1]: Sampling-based algorithms for optimal motion planning (https://core.ac.uk/reader/18173530)
